# -*- coding: Latin-1 -*-
#
# SMM Share and Money Management
# Copyright (c) 2007-2009 Carsten Grohmann
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; version 2 of the
# License.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.

## \file smm/__init__.py
#
# \short Summarise all stuff in one point
#
# \author Carsten Grohmann <mail (at) carstengrohmann (dot) de>
#
# \par License:
# GPL version 2.0

## \page index Share and Money Manegement (SMM)
#
# \par Beschreibung:
# SMM ist ein deutschsprachiges Programm zum Verwalten eines privaten
# Werpapierportfolio.
#  
# \par
# Mit SMM knnen Sie die einzelnen Positionen Ihres Depots in einem Programm
# verwalten. Dazu werden alle Wertpapiere und die dazugehrigen Transaktionen
# verwaltet. Damit haben Sie jederzeit einen berblick ber Ihre Anlage.
#
# \par
# Weiterhin knnen Sie die Entwicklung einzelner Positionen, seien es
# aktuelle offene oder auch geschlossenen Positionen ansehen oder sich einen
# Bericht zum Ausdrucken erstellen lassen. Sie knnen sich auch die
# Entwicklung Ihres einzelnen Bestandes ber einen frei whlbaren Zeitraum
# darstellen lassen.
#
# \par
# Es lt sich eine Liste (s.g. Watchlist) mit interessanten Wertpapieren,
# die Sie beobachten mchten, parallel zum aktuellen Bestand fhren. 
#
# \par
# Das Programm bietet eine komfortable Oberflche, ber die sich fast alle
# Aktionen ttigen lassen. Es sind noch nicht alle Mglichkeiten
# implementiert, so ist es zum Beispiel derzeit nicht mglich Transaktionen
# nachtrglich ber die Oberflche zu ndern.
#
# \par
# Eine Unterscheidung zwischen verschiedenen Depots ist nicht mglich.
# Ebenso wenig existieren Schnittstellen zu Banken, weder um das Portfolio
# automatisch abzugleichen noch um Transaktionen zu ttigen.
#
# \par Anforderungen:
# \li wxPython Version 2.8
# \li Python 2.5 oder neuer, empfohlen 2.5.2 oder neuer
#
# Grundstzlich luft dieses Programm mit jeder Python-Version ab Version
# 2.5.0. Die Versionen vor 2.5.2 enthalten mglicherweise Fehler, durch
# die teilweise keine Kurse von verschiedenen Internet-Seiten abgeholt
# werden knnen.
#
# \author  Carsten Grohmann <mail (at) carstengrohmann (dot) de>
# 
# \par Lizenz:
# Dieses Programm ist freie Software. Sie knnen es unter den
# Bedingungen der GNU General Public License, wie von der Free Software
# Foundation verffentlicht, weitergeben und/oder modifizieren, entweder
# gem Version 2 der Lizenz.
#
# \par
# Die Verffentlichung dieses Programms erfolgt in der Hoffnung, da es
# Ihnen von Nutzen sein wird, aber OHNE IRGENDEINE GARANTIE, sogar ohne
# die implizite Garantie der MARKTREIFE oder der VERWENDBARKEIT FR EINEN
# BESTIMMTEN ZWECK. Details finden Sie in der GNU General Public License. 
#
# \par
# Sie sollten ein Exemplar der GNU General Public License zusammen mit
# diesem Programm erhalten haben. Falls nicht, schreiben Sie an die Free
# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
# 02110, USA.
#
# \par Software Dritter:
# "Share and Money Management" hat folgende Software Dritter, die verschieden
# lizenziert ist, integriert:
#  - Beautiful Soup ("New-style BSD" Lizenz)
#  - Storm  (GNU Lesser General Public License (LGPL) Version 2.1)
#  - Mako template library (MIT-Lizenz)
#
# \par
# Details zu den einzelnen Lizenzen befinden sich in den individuellen
# Softwarepaketen.

## \page resources Web-Ressourcen und Beispiele
#
# \section web_ressources Ressourcen im Internet
# \li http://www.giombetti.com/snippets/14
# \li http://www.freenet.org.nz/python/yahooquote/
# \li http://mail.python.org/pipermail/python-list/2004-June/227308.html
# \li http://www.crummy.com/software/BeautifulSoup/
# \li http://developer.berlios.de/projects/pystocks/
# \li http://threshold.atlantic.net/~jjames/projects/YahooQuote/latest.tgz
# \li http://de.wikipedia.org/wiki/Liste_der_Unicode-Zeichen
# \li http://unicode.e-workers.de/
# \li http://halvar.at/python/wxpython_internationalisieren/
# \li http://p-nand-q.com/python/unicode_faq.html
#
# \section charts Diagramme
# \li http://home.gna.org/pychart/
# \li http://matplotlib.sourceforge.net/
# \li wx.lib.plot.py
#
# \section templates Template Engines
# \li http://www.cheetahtemplate.org
# \li http://www.makotemplates.org
#
# \section examples Beispiele
# \li http://de.finance.yahoo.com/q/hp?s=BMW.DE&b=3&a=00&c=2000&e=24&d=05&f=2006&g=d
# \li http://ichart.yahoo.com/table.csv?s=BMW.DE&a=00&b=3&c=2000&d=05&e=24&f=2006&g=d&ignore=.csv
#
# \section additional_software Zustzliche Software
# \li http://sqliteman.com/
# \li http://sqlitebrowser.sf.net

# import general python modules
import atexit
import gettext
import decimal
import os.path

# initiate dummy Unicode instance
gettext.NullTranslations().install(True)

# import external libs
from storm.locals import *
import storm

# import project modules
from objects import *
from operations import *
from quote import *
import database
import db_setup


# initialise variables

## Version number of all SMM stuff
version = "0.16"

## Version of the Storm ORM wrapper
storm_version = storm.version

## The %database URI
db_uri = "sqlite:./smm.db"

## Check if the %database exists
#
#  \return True if the %database exists
#  \see db_uri
def has_database():
    schema, params = db_uri.split(':', 1)
    if not schema == 'sqlite':
        logging.error(u'Nicht untersttzter Datenbanktyp: %s', schema)
        return False
    if not os.path.isfile(params):
        logging.error(u'Die Datenbankdatei %s existiert nicht', params)
        return False
    if not os.access(params, os.W_OK):
        logging.error(u'Die Datenbankdatei %s ist nicht schreibbar', params)
        return False
    if schema == 'sqlite' and not os.path.getsize(params):
        logging.error(u'Die Datenbankdatei %s ist 0 Byte gro', params)
        return False
    return True

## Initialise main SMM functionality like %database connections
#
#  \param debug: Enable tracing of the Storm ORM wrapper
def init(debug=False):

    # Set proper settings for Decimal objects
    ctx = decimal.getcontext()
    ctx.rounding=decimal.ROUND_HALF_UP

    database.init_storm(db_uri)

    # register deinit function to execute it at exit
    atexit.register(deinit)

    # enable storm debugging
    if debug:
        from storm.tracer import debug
        debug(True, stream=sys.stdout)

    # search and register fetch plugins
    quote.search_and_register()


## Closes all open stuff
#
#   Currently the open changes will be written in the %database only.
def deinit():
    database.close_storm()
