#!/usr/bin/env  python
# -*- coding: Latin-1 -*-
#
# SMM Share and Money Management
# Copyright (c) 2007-2009 Carsten Grohmann
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; version 2 of the
# License.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.

## \file test.py
#
# \short Runs all tests
# 
# \author Carsten Grohmann <mail (at) carstengrohmann (dot) de>
#
# \par License:
# GPL version 2.0
#
# \version $Id: test.py,v 1.10 2009-04-06 13:36:25 carsten Exp $
#
# \par Revision History:
# \code
# $Log: test.py,v $
# Revision 1.10  2009-04-06 13:36:25  carsten
# - typo in license statement
#
# Revision 1.9  2009-04-06 07:56:19  carsten
# - update copyright string
# - unify python coding line
#
# Revision 1.8  2009-02-07 15:36:55  carsten
# - rework loading test modules
#   all python files in the test directory will checked for test cases
#
# Revision 1.7  2009-01-03 13:31:02  carsten
# - remove empty test suite tests_finance
#
# Revision 1.6  2008-12-30 21:11:45  carsten
# - remove tests for (also removed) helper module
#
# Revision 1.5  2008-04-27 19:50:31  carsten
# - replace "stock" by "share" - I like British English :-)
#
# Revision 1.4  2008-04-10 19:43:14  carsten
# - add tests from tests/test_finance.py
#
# Revision 1.3  2008-01-24 21:24:32  carsten
# - import and perform tests from tests/test_helper.py
#
# Revision 1.2  2008-01-01 18:52:18  carsten
# - adapt copyright string to new year
#
# Revision 1.1  2007-12-25 19:10:17  carsten
# - Initial import of the current partly running version
# \endcode

# import general python modules
import imp
import os
import unittest


## \brief Create test suites and run all tests
def run_tests():
    suites = []

    # get a list of all test modules
    modules = os.listdir('./tests')
    if '__init__.py' in modules:
        modules.remove('__init__.py')

    # try to import all files as modules
    for module_name in modules:
        if not module_name.endswith('.py'):
            continue
        module_name = os.path.splitext(module_name)[0]
        fp, path, info = imp.find_module(module_name, ['./tests'])
        try:
            module = imp.load_module(module_name, fp, path, info)

        finally:
            # Make sure fp is closed properly
            if fp:
                fp.close()
           
        # search all testcases in the loaded module
        suites.append(unittest.findTestCases(module))

    # summarise all suites and run tests
    all_tests = unittest.TestSuite(suites)
    unittest.TextTestRunner(verbosity=2).run(all_tests)
    

if __name__ == '__main__':
    run_tests()
